# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from watchtowerrpc import watchtower_pb2 as watchtowerrpc_dot_watchtower__pb2


class WatchtowerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetInfo = channel.unary_unary(
        '/watchtowerrpc.Watchtower/GetInfo',
        request_serializer=watchtowerrpc_dot_watchtower__pb2.GetInfoRequest.SerializeToString,
        response_deserializer=watchtowerrpc_dot_watchtower__pb2.GetInfoResponse.FromString,
        )


class WatchtowerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetInfo(self, request, context):
    """* lncli: tower info
    GetInfo returns general information concerning the companion watchtower
    including it's public key and URIs where the server is currently
    listening for clients.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_WatchtowerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetInfo': grpc.unary_unary_rpc_method_handler(
          servicer.GetInfo,
          request_deserializer=watchtowerrpc_dot_watchtower__pb2.GetInfoRequest.FromString,
          response_serializer=watchtowerrpc_dot_watchtower__pb2.GetInfoResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'watchtowerrpc.Watchtower', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from signrpc import signer_pb2 as signrpc_dot_signer__pb2
from walletrpc import walletkit_pb2 as walletrpc_dot_walletkit__pb2


class WalletKitStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.DeriveNextKey = channel.unary_unary(
        '/walletrpc.WalletKit/DeriveNextKey',
        request_serializer=walletrpc_dot_walletkit__pb2.KeyReq.SerializeToString,
        response_deserializer=signrpc_dot_signer__pb2.KeyDescriptor.FromString,
        )
    self.DeriveKey = channel.unary_unary(
        '/walletrpc.WalletKit/DeriveKey',
        request_serializer=signrpc_dot_signer__pb2.KeyLocator.SerializeToString,
        response_deserializer=signrpc_dot_signer__pb2.KeyDescriptor.FromString,
        )
    self.NextAddr = channel.unary_unary(
        '/walletrpc.WalletKit/NextAddr',
        request_serializer=walletrpc_dot_walletkit__pb2.AddrRequest.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.AddrResponse.FromString,
        )
    self.PublishTransaction = channel.unary_unary(
        '/walletrpc.WalletKit/PublishTransaction',
        request_serializer=walletrpc_dot_walletkit__pb2.Transaction.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.PublishResponse.FromString,
        )
    self.SendOutputs = channel.unary_unary(
        '/walletrpc.WalletKit/SendOutputs',
        request_serializer=walletrpc_dot_walletkit__pb2.SendOutputsRequest.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.SendOutputsResponse.FromString,
        )
    self.EstimateFee = channel.unary_unary(
        '/walletrpc.WalletKit/EstimateFee',
        request_serializer=walletrpc_dot_walletkit__pb2.EstimateFeeRequest.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.EstimateFeeResponse.FromString,
        )
    self.PendingSweeps = channel.unary_unary(
        '/walletrpc.WalletKit/PendingSweeps',
        request_serializer=walletrpc_dot_walletkit__pb2.PendingSweepsRequest.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.PendingSweepsResponse.FromString,
        )
    self.BumpFee = channel.unary_unary(
        '/walletrpc.WalletKit/BumpFee',
        request_serializer=walletrpc_dot_walletkit__pb2.BumpFeeRequest.SerializeToString,
        response_deserializer=walletrpc_dot_walletkit__pb2.BumpFeeResponse.FromString,
        )


class WalletKitServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def DeriveNextKey(self, request, context):
    """*
    DeriveNextKey attempts to derive the *next* key within the key family
    (account in BIP43) specified. This method should return the next external
    child within this branch.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeriveKey(self, request, context):
    """*
    DeriveKey attempts to derive an arbitrary key specified by the passed
    KeyLocator. 
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def NextAddr(self, request, context):
    """*
    NextAddr returns the next unused address within the wallet.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PublishTransaction(self, request, context):
    """*
    PublishTransaction attempts to publish the passed transaction to the
    network. Once this returns without an error, the wallet will continually
    attempt to re-broadcast the transaction on start up, until it enters the
    chain.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SendOutputs(self, request, context):
    """*
    SendOutputs is similar to the existing sendmany call in Bitcoind, and
    allows the caller to create a transaction that sends to several outputs at
    once. This is ideal when wanting to batch create a set of transactions.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EstimateFee(self, request, context):
    """*
    EstimateFee attempts to query the internal fee estimator of the wallet to
    determine the fee (in sat/kw) to attach to a transaction in order to
    achieve the confirmation target.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PendingSweeps(self, request, context):
    """
    PendingSweeps returns lists of on-chain outputs that lnd is currently
    attempting to sweep within its central batching engine. Outputs with similar
    fee rates are batched together in order to sweep them within a single
    transaction.

    NOTE: Some of the fields within PendingSweepsRequest are not guaranteed to
    remain supported. This is an advanced API that depends on the internals of
    the UtxoSweeper, so things may change.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BumpFee(self, request, context):
    """
    BumpFee bumps the fee of an arbitrary input within a transaction. This RPC
    takes a different approach than bitcoind's bumpfee command. lnd has a
    central batching engine in which inputs with similar fee rates are batched
    together to save on transaction fees. Due to this, we cannot rely on
    bumping the fee on a specific transaction, since transactions can change at
    any point with the addition of new inputs. The list of inputs that
    currently exist within lnd's central batching engine can be retrieved
    through the PendingSweeps RPC.

    When bumping the fee of an input that currently exists within lnd's central
    batching engine, a higher fee transaction will be created that replaces the
    lower fee transaction through the Replace-By-Fee (RBF) policy. If it

    This RPC also serves useful when wanting to perform a Child-Pays-For-Parent
    (CPFP), where the child transaction pays for its parent's fee. This can be
    done by specifying an outpoint within the low fee transaction that is under
    the control of the wallet.

    The fee preference can be expressed either as a specific fee rate or a delta
    of blocks in which the output should be swept on-chain within. If a fee
    preference is not explicitly specified, then an error is returned.

    Note that this RPC currently doesn't perform any validation checks on the
    fee preference being provided. For now, the responsibility of ensuring that
    the new fee preference is sufficient is delegated to the user.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_WalletKitServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'DeriveNextKey': grpc.unary_unary_rpc_method_handler(
          servicer.DeriveNextKey,
          request_deserializer=walletrpc_dot_walletkit__pb2.KeyReq.FromString,
          response_serializer=signrpc_dot_signer__pb2.KeyDescriptor.SerializeToString,
      ),
      'DeriveKey': grpc.unary_unary_rpc_method_handler(
          servicer.DeriveKey,
          request_deserializer=signrpc_dot_signer__pb2.KeyLocator.FromString,
          response_serializer=signrpc_dot_signer__pb2.KeyDescriptor.SerializeToString,
      ),
      'NextAddr': grpc.unary_unary_rpc_method_handler(
          servicer.NextAddr,
          request_deserializer=walletrpc_dot_walletkit__pb2.AddrRequest.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.AddrResponse.SerializeToString,
      ),
      'PublishTransaction': grpc.unary_unary_rpc_method_handler(
          servicer.PublishTransaction,
          request_deserializer=walletrpc_dot_walletkit__pb2.Transaction.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.PublishResponse.SerializeToString,
      ),
      'SendOutputs': grpc.unary_unary_rpc_method_handler(
          servicer.SendOutputs,
          request_deserializer=walletrpc_dot_walletkit__pb2.SendOutputsRequest.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.SendOutputsResponse.SerializeToString,
      ),
      'EstimateFee': grpc.unary_unary_rpc_method_handler(
          servicer.EstimateFee,
          request_deserializer=walletrpc_dot_walletkit__pb2.EstimateFeeRequest.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.EstimateFeeResponse.SerializeToString,
      ),
      'PendingSweeps': grpc.unary_unary_rpc_method_handler(
          servicer.PendingSweeps,
          request_deserializer=walletrpc_dot_walletkit__pb2.PendingSweepsRequest.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.PendingSweepsResponse.SerializeToString,
      ),
      'BumpFee': grpc.unary_unary_rpc_method_handler(
          servicer.BumpFee,
          request_deserializer=walletrpc_dot_walletkit__pb2.BumpFeeRequest.FromString,
          response_serializer=walletrpc_dot_walletkit__pb2.BumpFeeResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'walletrpc.WalletKit', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from wtclientrpc import wtclient_pb2 as wtclientrpc_dot_wtclient__pb2


class WatchtowerClientStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.AddTower = channel.unary_unary(
        '/wtclientrpc.WatchtowerClient/AddTower',
        request_serializer=wtclientrpc_dot_wtclient__pb2.AddTowerRequest.SerializeToString,
        response_deserializer=wtclientrpc_dot_wtclient__pb2.AddTowerResponse.FromString,
        )
    self.RemoveTower = channel.unary_unary(
        '/wtclientrpc.WatchtowerClient/RemoveTower',
        request_serializer=wtclientrpc_dot_wtclient__pb2.RemoveTowerRequest.SerializeToString,
        response_deserializer=wtclientrpc_dot_wtclient__pb2.RemoveTowerResponse.FromString,
        )
    self.ListTowers = channel.unary_unary(
        '/wtclientrpc.WatchtowerClient/ListTowers',
        request_serializer=wtclientrpc_dot_wtclient__pb2.ListTowersRequest.SerializeToString,
        response_deserializer=wtclientrpc_dot_wtclient__pb2.ListTowersResponse.FromString,
        )
    self.GetTowerInfo = channel.unary_unary(
        '/wtclientrpc.WatchtowerClient/GetTowerInfo',
        request_serializer=wtclientrpc_dot_wtclient__pb2.GetTowerInfoRequest.SerializeToString,
        response_deserializer=wtclientrpc_dot_wtclient__pb2.Tower.FromString,
        )
    self.Stats = channel.unary_unary(
        '/wtclientrpc.WatchtowerClient/Stats',
        request_serializer=wtclientrpc_dot_wtclient__pb2.StatsRequest.SerializeToString,
        response_deserializer=wtclientrpc_dot_wtclient__pb2.StatsResponse.FromString,
        )
    self.Policy = channel.unary_unary(
        '/wtclientrpc.WatchtowerClient/Policy',
        request_serializer=wtclientrpc_dot_wtclient__pb2.PolicyRequest.SerializeToString,
        response_deserializer=wtclientrpc_dot_wtclient__pb2.PolicyResponse.FromString,
        )


class WatchtowerClientServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def AddTower(self, request, context):
    """
    AddTower adds a new watchtower reachable at the given address and
    considers it for new sessions. If the watchtower already exists, then
    any new addresses included will be considered when dialing it for
    session negotiations and backups.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveTower(self, request, context):
    """
    RemoveTower removes a watchtower from being considered for future session
    negotiations and from being used for any subsequent backups until it's added
    again. If an address is provided, then this RPC only serves as a way of
    removing the address from the watchtower instead.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListTowers(self, request, context):
    """ListTowers returns the list of watchtowers registered with the client. 
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTowerInfo(self, request, context):
    """GetTowerInfo retrieves information for a registered watchtower.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Stats(self, request, context):
    """Stats returns the in-memory statistics of the client since startup.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Policy(self, request, context):
    """Policy returns the active watchtower client policy configuration.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_WatchtowerClientServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'AddTower': grpc.unary_unary_rpc_method_handler(
          servicer.AddTower,
          request_deserializer=wtclientrpc_dot_wtclient__pb2.AddTowerRequest.FromString,
          response_serializer=wtclientrpc_dot_wtclient__pb2.AddTowerResponse.SerializeToString,
      ),
      'RemoveTower': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveTower,
          request_deserializer=wtclientrpc_dot_wtclient__pb2.RemoveTowerRequest.FromString,
          response_serializer=wtclientrpc_dot_wtclient__pb2.RemoveTowerResponse.SerializeToString,
      ),
      'ListTowers': grpc.unary_unary_rpc_method_handler(
          servicer.ListTowers,
          request_deserializer=wtclientrpc_dot_wtclient__pb2.ListTowersRequest.FromString,
          response_serializer=wtclientrpc_dot_wtclient__pb2.ListTowersResponse.SerializeToString,
      ),
      'GetTowerInfo': grpc.unary_unary_rpc_method_handler(
          servicer.GetTowerInfo,
          request_deserializer=wtclientrpc_dot_wtclient__pb2.GetTowerInfoRequest.FromString,
          response_serializer=wtclientrpc_dot_wtclient__pb2.Tower.SerializeToString,
      ),
      'Stats': grpc.unary_unary_rpc_method_handler(
          servicer.Stats,
          request_deserializer=wtclientrpc_dot_wtclient__pb2.StatsRequest.FromString,
          response_serializer=wtclientrpc_dot_wtclient__pb2.StatsResponse.SerializeToString,
      ),
      'Policy': grpc.unary_unary_rpc_method_handler(
          servicer.Policy,
          request_deserializer=wtclientrpc_dot_wtclient__pb2.PolicyRequest.FromString,
          response_serializer=wtclientrpc_dot_wtclient__pb2.PolicyResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'wtclientrpc.WatchtowerClient', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: routerrpc/router.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from lnrpc import rpc_pb2 as lnrpc_dot_rpc__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='routerrpc/router.proto',
  package='routerrpc',
  syntax='proto3',
  serialized_options=_b('Z.github.com/lncm/lnd-rpc/v0.8.2/lnrpc/routerrpc'),
  serialized_pb=_b('\n\x16routerrpc/router.proto\x12\trouterrpc\x1a\x0flnrpc/rpc.proto\"\xf8\x02\n\x12SendPaymentRequest\x12\x0c\n\x04\x64\x65st\x18\x01 \x01(\x0c\x12\x0b\n\x03\x61mt\x18\x02 \x01(\x03\x12\x14\n\x0cpayment_hash\x18\x03 \x01(\x0c\x12\x18\n\x10\x66inal_cltv_delta\x18\x04 \x01(\x05\x12\x17\n\x0fpayment_request\x18\x05 \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\x06 \x01(\x05\x12\x15\n\rfee_limit_sat\x18\x07 \x01(\x03\x12\x18\n\x10outgoing_chan_id\x18\x08 \x01(\x04\x12\x12\n\ncltv_limit\x18\t \x01(\x05\x12\x32\n\x0broute_hints\x18\n \x03(\x0b\x32\x10.lnrpc.RouteHintR\x0broute_hints\x12<\n\x08\x64\x65st_tlv\x18\x0b \x03(\x0b\x32*.routerrpc.SendPaymentRequest.DestTlvEntry\x1a.\n\x0c\x44\x65stTlvEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x13TrackPaymentRequest\x12\x14\n\x0cpayment_hash\x18\x01 \x01(\x0c\"f\n\rPaymentStatus\x12&\n\x05state\x18\x01 \x01(\x0e\x32\x17.routerrpc.PaymentState\x12\x10\n\x08preimage\x18\x02 \x01(\x0c\x12\x1b\n\x05route\x18\x03 \x01(\x0b\x32\x0c.lnrpc.Route\"0\n\x0fRouteFeeRequest\x12\x0c\n\x04\x64\x65st\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61mt_sat\x18\x02 \x01(\x03\"E\n\x10RouteFeeResponse\x12\x18\n\x10routing_fee_msat\x18\x01 \x01(\x03\x12\x17\n\x0ftime_lock_delay\x18\x02 \x01(\x03\"G\n\x12SendToRouteRequest\x12\x14\n\x0cpayment_hash\x18\x01 \x01(\x0c\x12\x1b\n\x05route\x18\x02 \x01(\x0b\x32\x0c.lnrpc.Route\"L\n\x13SendToRouteResponse\x12\x10\n\x08preimage\x18\x01 \x01(\x0c\x12#\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x12.routerrpc.Failure\"\x9a\x07\n\x07\x46\x61ilure\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x1e.routerrpc.Failure.FailureCode\x12\x30\n\x0e\x63hannel_update\x18\x03 \x01(\x0b\x32\x18.routerrpc.ChannelUpdate\x12\x11\n\thtlc_msat\x18\x04 \x01(\x04\x12\x15\n\ronion_sha_256\x18\x05 \x01(\x0c\x12\x13\n\x0b\x63ltv_expiry\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12\x1c\n\x14\x66\x61ilure_source_index\x18\x08 \x01(\r\x12\x0e\n\x06height\x18\t \x01(\r\"\xac\x05\n\x0b\x46\x61ilureCode\x12\x0c\n\x08RESERVED\x10\x00\x12(\n$INCORRECT_OR_UNKNOWN_PAYMENT_DETAILS\x10\x01\x12\x1c\n\x18INCORRECT_PAYMENT_AMOUNT\x10\x02\x12\x1f\n\x1b\x46INAL_INCORRECT_CLTV_EXPIRY\x10\x03\x12\x1f\n\x1b\x46INAL_INCORRECT_HTLC_AMOUNT\x10\x04\x12\x19\n\x15\x46INAL_EXPIRY_TOO_SOON\x10\x05\x12\x11\n\rINVALID_REALM\x10\x06\x12\x13\n\x0f\x45XPIRY_TOO_SOON\x10\x07\x12\x19\n\x15INVALID_ONION_VERSION\x10\x08\x12\x16\n\x12INVALID_ONION_HMAC\x10\t\x12\x15\n\x11INVALID_ONION_KEY\x10\n\x12\x18\n\x14\x41MOUNT_BELOW_MINIMUM\x10\x0b\x12\x14\n\x10\x46\x45\x45_INSUFFICIENT\x10\x0c\x12\x19\n\x15INCORRECT_CLTV_EXPIRY\x10\r\x12\x14\n\x10\x43HANNEL_DISABLED\x10\x0e\x12\x1d\n\x19TEMPORARY_CHANNEL_FAILURE\x10\x0f\x12!\n\x1dREQUIRED_NODE_FEATURE_MISSING\x10\x10\x12$\n REQUIRED_CHANNEL_FEATURE_MISSING\x10\x11\x12\x15\n\x11UNKNOWN_NEXT_PEER\x10\x12\x12\x1a\n\x16TEMPORARY_NODE_FAILURE\x10\x13\x12\x1a\n\x16PERMANENT_NODE_FAILURE\x10\x14\x12\x1d\n\x19PERMANENT_CHANNEL_FAILURE\x10\x15\x12\x12\n\x0e\x45XPIRY_TOO_FAR\x10\x16\x12\x14\n\x0fUNKNOWN_FAILURE\x10\xe6\x07\x12\x17\n\x12UNREADABLE_FAILURE\x10\xe7\x07J\x04\x08\x02\x10\x03\"\x96\x02\n\rChannelUpdate\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12\x12\n\nchain_hash\x18\x02 \x01(\x0c\x12\x0f\n\x07\x63han_id\x18\x03 \x01(\x04\x12\x11\n\ttimestamp\x18\x04 \x01(\r\x12\x15\n\rmessage_flags\x18\n \x01(\r\x12\x15\n\rchannel_flags\x18\x05 \x01(\r\x12\x17\n\x0ftime_lock_delta\x18\x06 \x01(\r\x12\x19\n\x11htlc_minimum_msat\x18\x07 \x01(\x04\x12\x10\n\x08\x62\x61se_fee\x18\x08 \x01(\r\x12\x10\n\x08\x66\x65\x65_rate\x18\t \x01(\r\x12\x19\n\x11htlc_maximum_msat\x18\x0b \x01(\x04\x12\x19\n\x11\x65xtra_opaque_data\x18\x0c \x01(\x0c\"\x1c\n\x1aResetMissionControlRequest\"\x1d\n\x1bResetMissionControlResponse\"\x1c\n\x1aQueryMissionControlRequest\"y\n\x1bQueryMissionControlResponse\x12,\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.routerrpc.NodeHistoryR\x05nodes\x12,\n\x05pairs\x18\x02 \x03(\x0b\x32\x16.routerrpc.PairHistoryR\x05pairs\"\x83\x01\n\x0bNodeHistory\x12\x16\n\x06pubkey\x18\x01 \x01(\x0cR\x06pubkey\x12&\n\x0elast_fail_time\x18\x02 \x01(\x03R\x0elast_fail_time\x12.\n\x12other_success_prob\x18\x03 \x01(\x02R\x12other_success_probJ\x04\x08\x04\x10\x05\"\xf5\x01\n\x0bPairHistory\x12\x1c\n\tnode_from\x18\x01 \x01(\x0cR\tnode_from\x12\x18\n\x07node_to\x18\x02 \x01(\x0cR\x07node_to\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\x12\x32\n\x14min_penalize_amt_sat\x18\x04 \x01(\x03R\x14min_penalize_amt_sat\x12\"\n\x0csuccess_prob\x18\x05 \x01(\x02R\x0csuccess_prob\x12\x38\n\x17last_attempt_successful\x18\x06 \x01(\x08R\x17last_attempt_successful\"n\n\x11\x42uildRouteRequest\x12\x10\n\x08\x61mt_msat\x18\x01 \x01(\x03\x12\x18\n\x10\x66inal_cltv_delta\x18\x02 \x01(\x05\x12\x18\n\x10outgoing_chan_id\x18\x03 \x01(\x04\x12\x13\n\x0bhop_pubkeys\x18\x04 \x03(\x0c\"1\n\x12\x42uildRouteResponse\x12\x1b\n\x05route\x18\x01 \x01(\x0b\x32\x0c.lnrpc.Route*\x8d\x01\n\x0cPaymentState\x12\r\n\tIN_FLIGHT\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\x12\n\x0e\x46\x41ILED_TIMEOUT\x10\x02\x12\x13\n\x0f\x46\x41ILED_NO_ROUTE\x10\x03\x12\x10\n\x0c\x46\x41ILED_ERROR\x10\x04\x12$\n FAILED_INCORRECT_PAYMENT_DETAILS\x10\x05\x32\xd0\x04\n\x06Router\x12H\n\x0bSendPayment\x12\x1d.routerrpc.SendPaymentRequest\x1a\x18.routerrpc.PaymentStatus0\x01\x12J\n\x0cTrackPayment\x12\x1e.routerrpc.TrackPaymentRequest\x1a\x18.routerrpc.PaymentStatus0\x01\x12K\n\x10\x45stimateRouteFee\x12\x1a.routerrpc.RouteFeeRequest\x1a\x1b.routerrpc.RouteFeeResponse\x12L\n\x0bSendToRoute\x12\x1d.routerrpc.SendToRouteRequest\x1a\x1e.routerrpc.SendToRouteResponse\x12\x64\n\x13ResetMissionControl\x12%.routerrpc.ResetMissionControlRequest\x1a&.routerrpc.ResetMissionControlResponse\x12\x64\n\x13QueryMissionControl\x12%.routerrpc.QueryMissionControlRequest\x1a&.routerrpc.QueryMissionControlResponse\x12I\n\nBuildRoute\x12\x1c.routerrpc.BuildRouteRequest\x1a\x1d.routerrpc.BuildRouteResponseB0Z.github.com/lncm/lnd-rpc/v0.8.2/lnrpc/routerrpcb\x06proto3')
  ,
  dependencies=[lnrpc_dot_rpc__pb2.DESCRIPTOR,])

_PAYMENTSTATE = _descriptor.EnumDescriptor(
  name='PaymentState',
  full_name='routerrpc.PaymentState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IN_FLIGHT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_NO_ROUTE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_INCORRECT_PAYMENT_DETAILS', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2820,
  serialized_end=2961,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTSTATE)

PaymentState = enum_type_wrapper.EnumTypeWrapper(_PAYMENTSTATE)
IN_FLIGHT = 0
SUCCEEDED = 1
FAILED_TIMEOUT = 2
FAILED_NO_ROUTE = 3
FAILED_ERROR = 4
FAILED_INCORRECT_PAYMENT_DETAILS = 5


_FAILURE_FAILURECODE = _descriptor.EnumDescriptor(
  name='FailureCode',
  full_name='routerrpc.Failure.FailureCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCORRECT_OR_UNKNOWN_PAYMENT_DETAILS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCORRECT_PAYMENT_AMOUNT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_INCORRECT_CLTV_EXPIRY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_INCORRECT_HTLC_AMOUNT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_EXPIRY_TOO_SOON', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REALM', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPIRY_TOO_SOON', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ONION_VERSION', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ONION_HMAC', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ONION_KEY', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AMOUNT_BELOW_MINIMUM', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEE_INSUFFICIENT', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCORRECT_CLTV_EXPIRY', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_DISABLED', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMPORARY_CHANNEL_FAILURE', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUIRED_NODE_FEATURE_MISSING', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUIRED_CHANNEL_FEATURE_MISSING', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_NEXT_PEER', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMPORARY_NODE_FAILURE', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMANENT_NODE_FAILURE', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMANENT_CHANNEL_FAILURE', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPIRY_TOO_FAR', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_FAILURE', index=23, number=998,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNREADABLE_FAILURE', index=24, number=999,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1087,
  serialized_end=1771,
)
_sym_db.RegisterEnumDescriptor(_FAILURE_FAILURECODE)


_SENDPAYMENTREQUEST_DESTTLVENTRY = _descriptor.Descriptor(
  name='DestTlvEntry',
  full_name='routerrpc.SendPaymentRequest.DestTlvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='routerrpc.SendPaymentRequest.DestTlvEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='routerrpc.SendPaymentRequest.DestTlvEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=431,
)

_SENDPAYMENTREQUEST = _descriptor.Descriptor(
  name='SendPaymentRequest',
  full_name='routerrpc.SendPaymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dest', full_name='routerrpc.SendPaymentRequest.dest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amt', full_name='routerrpc.SendPaymentRequest.amt', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.SendPaymentRequest.payment_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_cltv_delta', full_name='routerrpc.SendPaymentRequest.final_cltv_delta', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_request', full_name='routerrpc.SendPaymentRequest.payment_request', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout_seconds', full_name='routerrpc.SendPaymentRequest.timeout_seconds', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee_limit_sat', full_name='routerrpc.SendPaymentRequest.fee_limit_sat', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outgoing_chan_id', full_name='routerrpc.SendPaymentRequest.outgoing_chan_id', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cltv_limit', full_name='routerrpc.SendPaymentRequest.cltv_limit', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route_hints', full_name='routerrpc.SendPaymentRequest.route_hints', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='route_hints', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dest_tlv', full_name='routerrpc.SendPaymentRequest.dest_tlv', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SENDPAYMENTREQUEST_DESTTLVENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=431,
)


_TRACKPAYMENTREQUEST = _descriptor.Descriptor(
  name='TrackPaymentRequest',
  full_name='routerrpc.TrackPaymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.TrackPaymentRequest.payment_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=476,
)


_PAYMENTSTATUS = _descriptor.Descriptor(
  name='PaymentStatus',
  full_name='routerrpc.PaymentStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='routerrpc.PaymentStatus.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preimage', full_name='routerrpc.PaymentStatus.preimage', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route', full_name='routerrpc.PaymentStatus.route', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=580,
)


_ROUTEFEEREQUEST = _descriptor.Descriptor(
  name='RouteFeeRequest',
  full_name='routerrpc.RouteFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dest', full_name='routerrpc.RouteFeeRequest.dest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amt_sat', full_name='routerrpc.RouteFeeRequest.amt_sat', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=630,
)


_ROUTEFEERESPONSE = _descriptor.Descriptor(
  name='RouteFeeResponse',
  full_name='routerrpc.RouteFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_fee_msat', full_name='routerrpc.RouteFeeResponse.routing_fee_msat', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_lock_delay', full_name='routerrpc.RouteFeeResponse.time_lock_delay', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=701,
)


_SENDTOROUTEREQUEST = _descriptor.Descriptor(
  name='SendToRouteRequest',
  full_name='routerrpc.SendToRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.SendToRouteRequest.payment_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route', full_name='routerrpc.SendToRouteRequest.route', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=774,
)


_SENDTOROUTERESPONSE = _descriptor.Descriptor(
  name='SendToRouteResponse',
  full_name='routerrpc.SendToRouteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='preimage', full_name='routerrpc.SendToRouteResponse.preimage', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='routerrpc.SendToRouteResponse.failure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=852,
)


_FAILURE = _descriptor.Descriptor(
  name='Failure',
  full_name='routerrpc.Failure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='routerrpc.Failure.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_update', full_name='routerrpc.Failure.channel_update', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='htlc_msat', full_name='routerrpc.Failure.htlc_msat', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onion_sha_256', full_name='routerrpc.Failure.onion_sha_256', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cltv_expiry', full_name='routerrpc.Failure.cltv_expiry', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='routerrpc.Failure.flags', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure_source_index', full_name='routerrpc.Failure.failure_source_index', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='routerrpc.Failure.height', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FAILURE_FAILURECODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=1777,
)


_CHANNELUPDATE = _descriptor.Descriptor(
  name='ChannelUpdate',
  full_name='routerrpc.ChannelUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='routerrpc.ChannelUpdate.signature', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chain_hash', full_name='routerrpc.ChannelUpdate.chain_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chan_id', full_name='routerrpc.ChannelUpdate.chan_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='routerrpc.ChannelUpdate.timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_flags', full_name='routerrpc.ChannelUpdate.message_flags', index=4,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_flags', full_name='routerrpc.ChannelUpdate.channel_flags', index=5,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_lock_delta', full_name='routerrpc.ChannelUpdate.time_lock_delta', index=6,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='htlc_minimum_msat', full_name='routerrpc.ChannelUpdate.htlc_minimum_msat', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_fee', full_name='routerrpc.ChannelUpdate.base_fee', index=8,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee_rate', full_name='routerrpc.ChannelUpdate.fee_rate', index=9,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='htlc_maximum_msat', full_name='routerrpc.ChannelUpdate.htlc_maximum_msat', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_opaque_data', full_name='routerrpc.ChannelUpdate.extra_opaque_data', index=11,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1780,
  serialized_end=2058,
)


_RESETMISSIONCONTROLREQUEST = _descriptor.Descriptor(
  name='ResetMissionControlRequest',
  full_name='routerrpc.ResetMissionControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2060,
  serialized_end=2088,
)


_RESETMISSIONCONTROLRESPONSE = _descriptor.Descriptor(
  name='ResetMissionControlResponse',
  full_name='routerrpc.ResetMissionControlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2090,
  serialized_end=2119,
)


_QUERYMISSIONCONTROLREQUEST = _descriptor.Descriptor(
  name='QueryMissionControlRequest',
  full_name='routerrpc.QueryMissionControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2121,
  serialized_end=2149,
)


_QUERYMISSIONCONTROLRESPONSE = _descriptor.Descriptor(
  name='QueryMissionControlResponse',
  full_name='routerrpc.QueryMissionControlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='routerrpc.QueryMissionControlResponse.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pairs', full_name='routerrpc.QueryMissionControlResponse.pairs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pairs', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2151,
  serialized_end=2272,
)


_NODEHISTORY = _descriptor.Descriptor(
  name='NodeHistory',
  full_name='routerrpc.NodeHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='routerrpc.NodeHistory.pubkey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubkey', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_fail_time', full_name='routerrpc.NodeHistory.last_fail_time', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='last_fail_time', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='other_success_prob', full_name='routerrpc.NodeHistory.other_success_prob', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='other_success_prob', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2275,
  serialized_end=2406,
)


_PAIRHISTORY = _descriptor.Descriptor(
  name='PairHistory',
  full_name='routerrpc.PairHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_from', full_name='routerrpc.PairHistory.node_from', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_from', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_to', full_name='routerrpc.PairHistory.node_to', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_to', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='routerrpc.PairHistory.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_penalize_amt_sat', full_name='routerrpc.PairHistory.min_penalize_amt_sat', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='min_penalize_amt_sat', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success_prob', full_name='routerrpc.PairHistory.success_prob', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='success_prob', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_attempt_successful', full_name='routerrpc.PairHistory.last_attempt_successful', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='last_attempt_successful', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2409,
  serialized_end=2654,
)


_BUILDROUTEREQUEST = _descriptor.Descriptor(
  name='BuildRouteRequest',
  full_name='routerrpc.BuildRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amt_msat', full_name='routerrpc.BuildRouteRequest.amt_msat', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_cltv_delta', full_name='routerrpc.BuildRouteRequest.final_cltv_delta', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outgoing_chan_id', full_name='routerrpc.BuildRouteRequest.outgoing_chan_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hop_pubkeys', full_name='routerrpc.BuildRouteRequest.hop_pubkeys', index=3,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2656,
  serialized_end=2766,
)


_BUILDROUTERESPONSE = _descriptor.Descriptor(
  name='BuildRouteResponse',
  full_name='routerrpc.BuildRouteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='route', full_name='routerrpc.BuildRouteResponse.route', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2768,
  serialized_end=2817,
)

_SENDPAYMENTREQUEST_DESTTLVENTRY.containing_type = _SENDPAYMENTREQUEST
_SENDPAYMENTREQUEST.fields_by_name['route_hints'].message_type = lnrpc_dot_rpc__pb2._ROUTEHINT
_SENDPAYMENTREQUEST.fields_by_name['dest_tlv'].message_type = _SENDPAYMENTREQUEST_DESTTLVENTRY
_PAYMENTSTATUS.fields_by_name['state'].enum_type = _PAYMENTSTATE
_PAYMENTSTATUS.fields_by_name['route'].message_type = lnrpc_dot_rpc__pb2._ROUTE
_SENDTOROUTEREQUEST.fields_by_name['route'].message_type = lnrpc_dot_rpc__pb2._ROUTE
_SENDTOROUTERESPONSE.fields_by_name['failure'].message_type = _FAILURE
_FAILURE.fields_by_name['code'].enum_type = _FAILURE_FAILURECODE
_FAILURE.fields_by_name['channel_update'].message_type = _CHANNELUPDATE
_FAILURE_FAILURECODE.containing_type = _FAILURE
_QUERYMISSIONCONTROLRESPONSE.fields_by_name['nodes'].message_type = _NODEHISTORY
_QUERYMISSIONCONTROLRESPONSE.fields_by_name['pairs'].message_type = _PAIRHISTORY
_BUILDROUTERESPONSE.fields_by_name['route'].message_type = lnrpc_dot_rpc__pb2._ROUTE
DESCRIPTOR.message_types_by_name['SendPaymentRequest'] = _SENDPAYMENTREQUEST
DESCRIPTOR.message_types_by_name['TrackPaymentRequest'] = _TRACKPAYMENTREQUEST
DESCRIPTOR.message_types_by_name['PaymentStatus'] = _PAYMENTSTATUS
DESCRIPTOR.message_types_by_name['RouteFeeRequest'] = _ROUTEFEEREQUEST
DESCRIPTOR.message_types_by_name['RouteFeeResponse'] = _ROUTEFEERESPONSE
DESCRIPTOR.message_types_by_name['SendToRouteRequest'] = _SENDTOROUTEREQUEST
DESCRIPTOR.message_types_by_name['SendToRouteResponse'] = _SENDTOROUTERESPONSE
DESCRIPTOR.message_types_by_name['Failure'] = _FAILURE
DESCRIPTOR.message_types_by_name['ChannelUpdate'] = _CHANNELUPDATE
DESCRIPTOR.message_types_by_name['ResetMissionControlRequest'] = _RESETMISSIONCONTROLREQUEST
DESCRIPTOR.message_types_by_name['ResetMissionControlResponse'] = _RESETMISSIONCONTROLRESPONSE
DESCRIPTOR.message_types_by_name['QueryMissionControlRequest'] = _QUERYMISSIONCONTROLREQUEST
DESCRIPTOR.message_types_by_name['QueryMissionControlResponse'] = _QUERYMISSIONCONTROLRESPONSE
DESCRIPTOR.message_types_by_name['NodeHistory'] = _NODEHISTORY
DESCRIPTOR.message_types_by_name['PairHistory'] = _PAIRHISTORY
DESCRIPTOR.message_types_by_name['BuildRouteRequest'] = _BUILDROUTEREQUEST
DESCRIPTOR.message_types_by_name['BuildRouteResponse'] = _BUILDROUTERESPONSE
DESCRIPTOR.enum_types_by_name['PaymentState'] = _PAYMENTSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SendPaymentRequest = _reflection.GeneratedProtocolMessageType('SendPaymentRequest', (_message.Message,), dict(

  DestTlvEntry = _reflection.GeneratedProtocolMessageType('DestTlvEntry', (_message.Message,), dict(
    DESCRIPTOR = _SENDPAYMENTREQUEST_DESTTLVENTRY,
    __module__ = 'routerrpc.router_pb2'
    # @@protoc_insertion_point(class_scope:routerrpc.SendPaymentRequest.DestTlvEntry)
    ))
  ,
  DESCRIPTOR = _SENDPAYMENTREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SendPaymentRequest)
  ))
_sym_db.RegisterMessage(SendPaymentRequest)
_sym_db.RegisterMessage(SendPaymentRequest.DestTlvEntry)

TrackPaymentRequest = _reflection.GeneratedProtocolMessageType('TrackPaymentRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRACKPAYMENTREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.TrackPaymentRequest)
  ))
_sym_db.RegisterMessage(TrackPaymentRequest)

PaymentStatus = _reflection.GeneratedProtocolMessageType('PaymentStatus', (_message.Message,), dict(
  DESCRIPTOR = _PAYMENTSTATUS,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PaymentStatus)
  ))
_sym_db.RegisterMessage(PaymentStatus)

RouteFeeRequest = _reflection.GeneratedProtocolMessageType('RouteFeeRequest', (_message.Message,), dict(
  DESCRIPTOR = _ROUTEFEEREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeRequest)
  ))
_sym_db.RegisterMessage(RouteFeeRequest)

RouteFeeResponse = _reflection.GeneratedProtocolMessageType('RouteFeeResponse', (_message.Message,), dict(
  DESCRIPTOR = _ROUTEFEERESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeResponse)
  ))
_sym_db.RegisterMessage(RouteFeeResponse)

SendToRouteRequest = _reflection.GeneratedProtocolMessageType('SendToRouteRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDTOROUTEREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SendToRouteRequest)
  ))
_sym_db.RegisterMessage(SendToRouteRequest)

SendToRouteResponse = _reflection.GeneratedProtocolMessageType('SendToRouteResponse', (_message.Message,), dict(
  DESCRIPTOR = _SENDTOROUTERESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SendToRouteResponse)
  ))
_sym_db.RegisterMessage(SendToRouteResponse)

Failure = _reflection.GeneratedProtocolMessageType('Failure', (_message.Message,), dict(
  DESCRIPTOR = _FAILURE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.Failure)
  ))
_sym_db.RegisterMessage(Failure)

ChannelUpdate = _reflection.GeneratedProtocolMessageType('ChannelUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELUPDATE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ChannelUpdate)
  ))
_sym_db.RegisterMessage(ChannelUpdate)

ResetMissionControlRequest = _reflection.GeneratedProtocolMessageType('ResetMissionControlRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESETMISSIONCONTROLREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ResetMissionControlRequest)
  ))
_sym_db.RegisterMessage(ResetMissionControlRequest)

ResetMissionControlResponse = _reflection.GeneratedProtocolMessageType('ResetMissionControlResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESETMISSIONCONTROLRESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ResetMissionControlResponse)
  ))
_sym_db.RegisterMessage(ResetMissionControlResponse)

QueryMissionControlRequest = _reflection.GeneratedProtocolMessageType('QueryMissionControlRequest', (_message.Message,), dict(
  DESCRIPTOR = _QUERYMISSIONCONTROLREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.QueryMissionControlRequest)
  ))
_sym_db.RegisterMessage(QueryMissionControlRequest)

QueryMissionControlResponse = _reflection.GeneratedProtocolMessageType('QueryMissionControlResponse', (_message.Message,), dict(
  DESCRIPTOR = _QUERYMISSIONCONTROLRESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.QueryMissionControlResponse)
  ))
_sym_db.RegisterMessage(QueryMissionControlResponse)

NodeHistory = _reflection.GeneratedProtocolMessageType('NodeHistory', (_message.Message,), dict(
  DESCRIPTOR = _NODEHISTORY,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.NodeHistory)
  ))
_sym_db.RegisterMessage(NodeHistory)

PairHistory = _reflection.GeneratedProtocolMessageType('PairHistory', (_message.Message,), dict(
  DESCRIPTOR = _PAIRHISTORY,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PairHistory)
  ))
_sym_db.RegisterMessage(PairHistory)

BuildRouteRequest = _reflection.GeneratedProtocolMessageType('BuildRouteRequest', (_message.Message,), dict(
  DESCRIPTOR = _BUILDROUTEREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.BuildRouteRequest)
  ))
_sym_db.RegisterMessage(BuildRouteRequest)

BuildRouteResponse = _reflection.GeneratedProtocolMessageType('BuildRouteResponse', (_message.Message,), dict(
  DESCRIPTOR = _BUILDROUTERESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.BuildRouteResponse)
  ))
_sym_db.RegisterMessage(BuildRouteResponse)


DESCRIPTOR._options = None
_SENDPAYMENTREQUEST_DESTTLVENTRY._options = None

_ROUTER = _descriptor.ServiceDescriptor(
  name='Router',
  full_name='routerrpc.Router',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2964,
  serialized_end=3556,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendPayment',
    full_name='routerrpc.Router.SendPayment',
    index=0,
    containing_service=None,
    input_type=_SENDPAYMENTREQUEST,
    output_type=_PAYMENTSTATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TrackPayment',
    full_name='routerrpc.Router.TrackPayment',
    index=1,
    containing_service=None,
    input_type=_TRACKPAYMENTREQUEST,
    output_type=_PAYMENTSTATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EstimateRouteFee',
    full_name='routerrpc.Router.EstimateRouteFee',
    index=2,
    containing_service=None,
    input_type=_ROUTEFEEREQUEST,
    output_type=_ROUTEFEERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendToRoute',
    full_name='routerrpc.Router.SendToRoute',
    index=3,
    containing_service=None,
    input_type=_SENDTOROUTEREQUEST,
    output_type=_SENDTOROUTERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ResetMissionControl',
    full_name='routerrpc.Router.ResetMissionControl',
    index=4,
    containing_service=None,
    input_type=_RESETMISSIONCONTROLREQUEST,
    output_type=_RESETMISSIONCONTROLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='QueryMissionControl',
    full_name='routerrpc.Router.QueryMissionControl',
    index=5,
    containing_service=None,
    input_type=_QUERYMISSIONCONTROLREQUEST,
    output_type=_QUERYMISSIONCONTROLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BuildRoute',
    full_name='routerrpc.Router.BuildRoute',
    index=6,
    containing_service=None,
    input_type=_BUILDROUTEREQUEST,
    output_type=_BUILDROUTERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROUTER)

DESCRIPTOR.services_by_name['Router'] = _ROUTER

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: autopilotrpc/autopilot.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='autopilotrpc/autopilot.proto',
  package='autopilotrpc',
  syntax='proto3',
  serialized_options=_b('Z1github.com/lncm/lnd-rpc/v0.8.2/lnrpc/autopilotrpc'),
  serialized_pb=_b('\n\x1c\x61utopilotrpc/autopilot.proto\x12\x0c\x61utopilotrpc\"\x0f\n\rStatusRequest\"(\n\x0eStatusResponse\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\"-\n\x13ModifyStatusRequest\x12\x16\n\x06\x65nable\x18\x01 \x01(\x08R\x06\x65nable\"\x16\n\x14ModifyStatusResponse\"T\n\x12QueryScoresRequest\x12\x18\n\x07pubkeys\x18\x01 \x03(\tR\x07pubkeys\x12$\n\x12ignore_local_state\x18\x02 \x01(\x08R\x08no_state\"\x9a\x02\n\x13QueryScoresResponse\x12K\n\x07results\x18\x01 \x03(\x0b\x32\x31.autopilotrpc.QueryScoresResponse.HeuristicResultR\x07results\x1a\xb5\x01\n\x0fHeuristicResult\x12\x1c\n\theuristic\x18\x01 \x01(\tR\theuristic\x12U\n\x06scores\x18\x02 \x03(\x0b\x32=.autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntryR\x06scores\x1a-\n\x0bScoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\xa3\x01\n\x10SetScoresRequest\x12\x1c\n\theuristic\x18\x01 \x01(\tR\theuristic\x12\x42\n\x06scores\x18\x02 \x03(\x0b\x32*.autopilotrpc.SetScoresRequest.ScoresEntryR\x06scores\x1a-\n\x0bScoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\x13\n\x11SetScoresResponse2\xc9\x02\n\tAutopilot\x12\x43\n\x06Status\x12\x1b.autopilotrpc.StatusRequest\x1a\x1c.autopilotrpc.StatusResponse\x12U\n\x0cModifyStatus\x12!.autopilotrpc.ModifyStatusRequest\x1a\".autopilotrpc.ModifyStatusResponse\x12R\n\x0bQueryScores\x12 .autopilotrpc.QueryScoresRequest\x1a!.autopilotrpc.QueryScoresResponse\x12L\n\tSetScores\x12\x1e.autopilotrpc.SetScoresRequest\x1a\x1f.autopilotrpc.SetScoresResponseB3Z1github.com/lncm/lnd-rpc/v0.8.2/lnrpc/autopilotrpcb\x06proto3')
)




_STATUSREQUEST = _descriptor.Descriptor(
  name='StatusRequest',
  full_name='autopilotrpc.StatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=61,
)


_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='autopilotrpc.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active', full_name='autopilotrpc.StatusResponse.active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='active', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=103,
)


_MODIFYSTATUSREQUEST = _descriptor.Descriptor(
  name='ModifyStatusRequest',
  full_name='autopilotrpc.ModifyStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='autopilotrpc.ModifyStatusRequest.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='enable', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=150,
)


_MODIFYSTATUSRESPONSE = _descriptor.Descriptor(
  name='ModifyStatusResponse',
  full_name='autopilotrpc.ModifyStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=174,
)


_QUERYSCORESREQUEST = _descriptor.Descriptor(
  name='QueryScoresRequest',
  full_name='autopilotrpc.QueryScoresRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubkeys', full_name='autopilotrpc.QueryScoresRequest.pubkeys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubkeys', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignore_local_state', full_name='autopilotrpc.QueryScoresRequest.ignore_local_state', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='no_state', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=260,
)


_QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY = _descriptor.Descriptor(
  name='ScoresEntry',
  full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=545,
)

_QUERYSCORESRESPONSE_HEURISTICRESULT = _descriptor.Descriptor(
  name='HeuristicResult',
  full_name='autopilotrpc.QueryScoresResponse.HeuristicResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heuristic', full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.heuristic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='heuristic', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scores', full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.scores', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scores', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=545,
)

_QUERYSCORESRESPONSE = _descriptor.Descriptor(
  name='QueryScoresResponse',
  full_name='autopilotrpc.QueryScoresResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='autopilotrpc.QueryScoresResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='results', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_QUERYSCORESRESPONSE_HEURISTICRESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=545,
)


_SETSCORESREQUEST_SCORESENTRY = _descriptor.Descriptor(
  name='ScoresEntry',
  full_name='autopilotrpc.SetScoresRequest.ScoresEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='autopilotrpc.SetScoresRequest.ScoresEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='autopilotrpc.SetScoresRequest.ScoresEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=545,
)

_SETSCORESREQUEST = _descriptor.Descriptor(
  name='SetScoresRequest',
  full_name='autopilotrpc.SetScoresRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heuristic', full_name='autopilotrpc.SetScoresRequest.heuristic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='heuristic', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scores', full_name='autopilotrpc.SetScoresRequest.scores', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scores', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SETSCORESREQUEST_SCORESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=711,
)


_SETSCORESRESPONSE = _descriptor.Descriptor(
  name='SetScoresResponse',
  full_name='autopilotrpc.SetScoresResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=732,
)

_QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY.containing_type = _QUERYSCORESRESPONSE_HEURISTICRESULT
_QUERYSCORESRESPONSE_HEURISTICRESULT.fields_by_name['scores'].message_type = _QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY
_QUERYSCORESRESPONSE_HEURISTICRESULT.containing_type = _QUERYSCORESRESPONSE
_QUERYSCORESRESPONSE.fields_by_name['results'].message_type = _QUERYSCORESRESPONSE_HEURISTICRESULT
_SETSCORESREQUEST_SCORESENTRY.containing_type = _SETSCORESREQUEST
_SETSCORESREQUEST.fields_by_name['scores'].message_type = _SETSCORESREQUEST_SCORESENTRY
DESCRIPTOR.message_types_by_name['StatusRequest'] = _STATUSREQUEST
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.message_types_by_name['ModifyStatusRequest'] = _MODIFYSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ModifyStatusResponse'] = _MODIFYSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['QueryScoresRequest'] = _QUERYSCORESREQUEST
DESCRIPTOR.message_types_by_name['QueryScoresResponse'] = _QUERYSCORESRESPONSE
DESCRIPTOR.message_types_by_name['SetScoresRequest'] = _SETSCORESREQUEST
DESCRIPTOR.message_types_by_name['SetScoresResponse'] = _SETSCORESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusRequest = _reflection.GeneratedProtocolMessageType('StatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATUSREQUEST,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.StatusRequest)
  ))
_sym_db.RegisterMessage(StatusRequest)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATUSRESPONSE,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.StatusResponse)
  ))
_sym_db.RegisterMessage(StatusResponse)

ModifyStatusRequest = _reflection.GeneratedProtocolMessageType('ModifyStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _MODIFYSTATUSREQUEST,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.ModifyStatusRequest)
  ))
_sym_db.RegisterMessage(ModifyStatusRequest)

ModifyStatusResponse = _reflection.GeneratedProtocolMessageType('ModifyStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _MODIFYSTATUSRESPONSE,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.ModifyStatusResponse)
  ))
_sym_db.RegisterMessage(ModifyStatusResponse)

QueryScoresRequest = _reflection.GeneratedProtocolMessageType('QueryScoresRequest', (_message.Message,), dict(
  DESCRIPTOR = _QUERYSCORESREQUEST,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.QueryScoresRequest)
  ))
_sym_db.RegisterMessage(QueryScoresRequest)

QueryScoresResponse = _reflection.GeneratedProtocolMessageType('QueryScoresResponse', (_message.Message,), dict(

  HeuristicResult = _reflection.GeneratedProtocolMessageType('HeuristicResult', (_message.Message,), dict(

    ScoresEntry = _reflection.GeneratedProtocolMessageType('ScoresEntry', (_message.Message,), dict(
      DESCRIPTOR = _QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY,
      __module__ = 'autopilotrpc.autopilot_pb2'
      # @@protoc_insertion_point(class_scope:autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntry)
      ))
    ,
    DESCRIPTOR = _QUERYSCORESRESPONSE_HEURISTICRESULT,
    __module__ = 'autopilotrpc.autopilot_pb2'
    # @@protoc_insertion_point(class_scope:autopilotrpc.QueryScoresResponse.HeuristicResult)
    ))
  ,
  DESCRIPTOR = _QUERYSCORESRESPONSE,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.QueryScoresResponse)
  ))
_sym_db.RegisterMessage(QueryScoresResponse)
_sym_db.RegisterMessage(QueryScoresResponse.HeuristicResult)
_sym_db.RegisterMessage(QueryScoresResponse.HeuristicResult.ScoresEntry)

SetScoresRequest = _reflection.GeneratedProtocolMessageType('SetScoresRequest', (_message.Message,), dict(

  ScoresEntry = _reflection.GeneratedProtocolMessageType('ScoresEntry', (_message.Message,), dict(
    DESCRIPTOR = _SETSCORESREQUEST_SCORESENTRY,
    __module__ = 'autopilotrpc.autopilot_pb2'
    # @@protoc_insertion_point(class_scope:autopilotrpc.SetScoresRequest.ScoresEntry)
    ))
  ,
  DESCRIPTOR = _SETSCORESREQUEST,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.SetScoresRequest)
  ))
_sym_db.RegisterMessage(SetScoresRequest)
_sym_db.RegisterMessage(SetScoresRequest.ScoresEntry)

SetScoresResponse = _reflection.GeneratedProtocolMessageType('SetScoresResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSCORESRESPONSE,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.SetScoresResponse)
  ))
_sym_db.RegisterMessage(SetScoresResponse)


DESCRIPTOR._options = None
_QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY._options = None
_SETSCORESREQUEST_SCORESENTRY._options = None

_AUTOPILOT = _descriptor.ServiceDescriptor(
  name='Autopilot',
  full_name='autopilotrpc.Autopilot',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=735,
  serialized_end=1064,
  methods=[
  _descriptor.MethodDescriptor(
    name='Status',
    full_name='autopilotrpc.Autopilot.Status',
    index=0,
    containing_service=None,
    input_type=_STATUSREQUEST,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyStatus',
    full_name='autopilotrpc.Autopilot.ModifyStatus',
    index=1,
    containing_service=None,
    input_type=_MODIFYSTATUSREQUEST,
    output_type=_MODIFYSTATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='QueryScores',
    full_name='autopilotrpc.Autopilot.QueryScores',
    index=2,
    containing_service=None,
    input_type=_QUERYSCORESREQUEST,
    output_type=_QUERYSCORESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetScores',
    full_name='autopilotrpc.Autopilot.SetScores',
    index=3,
    containing_service=None,
    input_type=_SETSCORESREQUEST,
    output_type=_SETSCORESRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTOPILOT)

DESCRIPTOR.services_by_name['Autopilot'] = _AUTOPILOT

# @@protoc_insertion_point(module_scope)
